#include <config.h>
#include <errno.h>
#include <stdarg.h>
#include <string.h>
#include <stdlib.h>
#include <unistd.h>
#include <gtk/gtk.h>
#include "libgnome/libgnome.h"
#include "gnome-colors.h"

void
gnome_init (int *argc, char ***argv)
{
	gnomelib_init (argc, argv);
	gnome_colors_init();
}
